@@ -63,7 +63,7 @@ parser.add_argument(
 )
 
 parser.add_argument(
-    "--steps", type=int, default=float("inf"), help="How many steps to perform"
+    "--steps", type=int, default=None, help="How many steps to perform"
 )
 
 parser.add_argument(
@@ -75,7 +75,6 @@ parser.add_argument(
 parser.add_argument(
     "--force",
     type=str,
-    action="append",
     default=None,
     help="choose first non-trivial variable to be assigned",
 )
@@ -88,6 +87,7 @@ parser.add_argument(
     help="optional JSON file output",
 )
 
+
 parser.add_argument(
     "--forqes",
     action="store_true",
@@ -122,9 +122,12 @@ if args.debuginfo:
     )
 
 demystify.config.LoadConfigFromDict(
-    {"repeats": args.repeats, "cores": args.cores, "earlyExit": not args.multiple}
+    {"repeats": args.repeats, "cores": args.cores}
 )
 
+if args.multiple:
+    demystify.config.LoadConfigFromDict(demystify.config.CONFIG_MORE_MUS)
+
 if args.forqes:
     mus_finder = "forqes"
 else:
@@ -137,7 +140,7 @@ if args.puzzle is not None:
     explainer.init_from_json(args.puzzle)
 else:
     name = os.path.basename(args.eprime)
-    explainer.init_from_essence(args.eprime, args.eprimeparam)
+    explainer.init_from_essence(args.eprime, args.eprimeparam, allow_incomplete=args.incomplete)
 
 if args.json is not None:
     output_path = args.json[0]
@@ -146,7 +149,14 @@ else:
 
 f = open(output_path, "w")
 
-output = explainer.explain_steps()
+if args.force is None:
+    forced_args = None
+else:
+    parse_args = [int(i) for i in args.force.split(",")]
+    forced_args = { "row": parse_args[0], "column": parse_args[1], "value": parse_args[2] }
+
+
+output = explainer.explain_steps(num_steps=args.steps, lit_choice=forced_args)
 
 f.write(json.dumps(output))
 
