@@ -8,7 +8,7 @@ from .musforqes import ForqesMUSFinder
 from .utils import flatten, in_flattened, intsqrt, lowsqrt
 from .base import EqVal, NeqVal
 
-from .config import getDefaultConfig
+from .config import getDefaultConfig, getMoreMusConfig
 
 from sortedcontainers import SortedSet
 
@@ -41,6 +41,13 @@ class Explainer(object):
         self.solver = None
         self.solution = None
         self.explained = []
+        self.config = self.get_config()
+
+    def get_config(self):
+        if self.mus_finder_name == "cascade-more":
+            return getMoreMusConfig()
+        else:
+            return getDefaultConfig()
 
     def init_from_json(self, puzzle_json):
         self.puzzle, self.solver = parse_json(puzzle_json)
@@ -48,12 +55,12 @@ class Explainer(object):
         self.unexplained = self.solution
         self._set_mus_finder()
 
-    def init_from_essence(self, eprime, eprimeparam):
+    def init_from_essence(self, eprime, eprimeparam, *, allow_incomplete=False):
         self.puzzle, self.solver, self.params = parse_essence(
             eprime, eprimeparam
         )
         self.name = os.path.basename(eprime)
-        self.solution = self._get_puzzle_solution()
+        self.solution = self._get_puzzle_solution(allow_incomplete=allow_incomplete)
         self.unexplained = self.solution
         self._set_mus_finder()
 
@@ -73,7 +80,7 @@ class Explainer(object):
                         )
                     )
                 else:
-                    steps.append(self.explain_step(self))
+                    steps.append(self.explain_step())
         else:
             first_step = True
             while len(self.unexplained) > 0:
@@ -85,7 +92,7 @@ class Explainer(object):
                     )
                     first_step = False
                 else:
-                    steps.append(self.explain_step(self))
+                    steps.append(self.explain_step())
 
         if len(self.unexplained) == 0:
             steps.append(self.get_solved_step())
@@ -138,9 +145,15 @@ class Explainer(object):
 
             self._add_known(merged)
         else:
-            lit_choices = mus_dict.filter_literals_by_mus(
-                lambda mus: len(mus) == smallest
-            )
+            if self.config["findLarger"]:
+                lit_choices = mus_dict.filter_literals_by_mus(
+                    lambda mus: 
+                        len(mus) >= smallest and len(mus) <= 3*smallest
+                )
+            else:
+                lit_choices = mus_dict.filter_literals_by_mus(
+                    lambda mus: len(mus) == smallest
+                )
 
             (
                 best_lit,
@@ -211,9 +224,15 @@ class Explainer(object):
         if smallest <= self.merge:
             return []
         else:
-            lit_choices = mus_dict.filter_literals_by_mus(
-                lambda mus: len(mus) == smallest
-            )
+            if self.config["findLarger"]:
+                lit_choices = mus_dict.filter_literals_by_mus(
+                    lambda mus: 
+                        len(mus) >= smallest and len(mus) <= 3*smallest
+                )
+            else:
+                lit_choices = mus_dict.filter_literals_by_mus(
+                    lambda mus: len(mus) == smallest
+                )
 
             (
                 _,
@@ -378,6 +397,7 @@ class Explainer(object):
             raise SolveError("Your problem has no solution!")
 
         if solution == "Multiple" and not allow_incomplete:
+
             raise SolveError("Your problem has multiple solutions!")
 
         if no_domains:
@@ -420,7 +440,7 @@ class Explainer(object):
                 if (len(mus), len(unexplained_in_mus)) < best_mus_stat:
                     proven_lits = SortedSet(
                         checkWhichLitsAMUSProves(
-                            self.solver, unexplained_in_mus, mus, getDefaultConfig()
+                            self.solver, unexplained_in_mus, mus, self.config
                         )
                     ).union(SortedSet([b]))
                 else:
@@ -439,8 +459,11 @@ class Explainer(object):
         return best_lit, best_mus, best_proven_lits, proven_dict
 
     def _set_mus_finder(self):
-        config = getDefaultConfig()
+        config = self.config
+
         if self.mus_finder_name == "forqes":
             self.mus_finder = ForqesMUSFinder(self.solver, config=config)
+        elif self.mus_finder_name == "cascade-more":
+            self.mus_finder = CascadeMUSFinder(self.solver, config=config)
         else:
             self.mus_finder = CascadeMUSFinder(self.solver, config=config)
